@@ -134,7 +134,7 @@ class CommunityMember(Model):
         anonymous_perms = ['view']
         authenticated_perms = ['inherit']
         superuser_perms = ['inherit']
-        unique_together = ['user', 'community']
+        # unique_together = ['user', 'community']
         container_path = "community-members/"
         serializer_fields = ['@id', 'community', 'user', 'is_admin']
         rdf_type = "as:items"
@@ -162,7 +162,7 @@ class CommunityCircle(Model):
         anonymous_perms = ['view']
         authenticated_perms = ['inherit']
         superuser_perms = ['inherit']
-        unique_together = ['circle', 'community']
+        # unique_together = ['circle', 'community']
         container_path = "community-circles/"
         serializer_fields = ['@id', 'community', 'circle']
         rdf_type = "as:items"
@@ -190,7 +190,7 @@ class CommunityProject(Model):
         anonymous_perms = ['view']
         authenticated_perms = ['inherit']
         superuser_perms = ['inherit']
-        unique_together = ['project', 'community']
+        # unique_together = ['project', 'community']
         container_path = "community-projects/"
         serializer_fields = ['@id', 'community', 'project']
         rdf_type = "as:items"
@@ -218,7 +218,7 @@ class CommunityJobOffer(Model):
         anonymous_perms = ['view']
         authenticated_perms = ['inherit']
         superuser_perms = ['inherit']
-        unique_together = ['joboffer', 'community']
+        # unique_together = ['joboffer', 'community']
         container_path = "community-joboffers/"
         serializer_fields = ['@id', 'community', 'joboffer']
         rdf_type = "as:items"
